tornado-transmute
=================

.. warn:: this project is in alpha. APIs may change without
          warning. Use at your own risk.

route generation from function signatures in Python, for the tornado framework

-------
Caveats
-------

* In alpha.
* transmute functions must be tornado coroutines.
